@@ -114,7 +114,11 @@ hd_plugin_loader_factory_init (HDPluginLoaderFactory *factory)
 {
   factory->priv = HD_PLUGIN_LOADER_FACTORY_GET_PRIVATE (factory);
 
-  factory->priv->registry = g_hash_table_new (g_str_hash, g_str_equal);
+  factory->priv->registry =
+    g_hash_table_new_full (g_str_hash, 
+	  		   g_str_equal,
+			   (GDestroyNotify) g_free,
+			   (GDestroyNotify) g_object_unref);
   
   factory->priv->modules  = 
     g_hash_table_new_full (g_str_hash, 
@@ -125,24 +129,6 @@ hd_plugin_loader_factory_init (HDPluginLoaderFactory *factory)
   hd_plugin_loader_factory_load_modules (factory);
 }
 
-static gboolean
-hd_plugin_loader_factory_free_loader (gchar *key, GObject *object)
-{
-  g_free (key);
-  g_object_unref (object);
-
-  return TRUE;
-}
-
-static gboolean 
-hd_plugin_loader_factory_free_modules (gchar *key, GModule *module)
-{
-  g_free (key);
-  g_module_close (module);
-
-  return TRUE;
-}
-
 static void
 hd_plugin_loader_factory_finalize (GObject *object)
 {
@@ -155,16 +141,11 @@ hd_plugin_loader_factory_finalize (GObject *object)
  
   if (priv->registry != NULL) 
   {
-    g_hash_table_foreach_remove (priv->registry, 
-                                 (GHRFunc) hd_plugin_loader_factory_free_loader, 
-                                 NULL);
-
-    g_hash_table_foreach_remove (priv->registry, 
-                                 (GHRFunc) hd_plugin_loader_factory_free_modules, 
-                                 NULL);
- 
-
     g_hash_table_destroy (priv->registry);
+  }
+
+  if (priv->modules != NULL) 
+  {
     g_hash_table_destroy (priv->modules);
   }
 
